@@ -14,6 +14,12 @@ class ExtensionTest(unittest.TestCase):
 
         self.assertIn('[bassdrive]', config)
         self.assertIn('enabled = true', config)
+        self.assertIn('refresh_archive = 1440', config)
+
+    def test_get_config_schema(self):
+        ext = BassdriveExtension()
+        schema = ext.get_config_schema()
+        self.assertIsNotNone(schema)
 
     def test_get_backend_classes(self):
         registry = mock.Mock()
